from setuptools import setup, find_packages

setup(
    name='area-fig',
    version='0.0.15',
    author='Kailash Lohar',
    author_email='kailash@aganitha.ai',
    description='Area and Perimeter calculator',
    long_description='A package to find area of square, rectangle, triangle and circle',
    packages=find_packages(),
    install_requires=[],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.11',
    ],
)
